@@ -638,6 +638,13 @@ def files_write( fp ) :
     with open( fp , "w" , 1 ) as f :
         f.write( files_getcontent( fp ) )
 
+def files_readallmeta( ) :
+
+    sql = "SELECT fp,fs,fh FROM files" 
+    rows = sql_execute_fetch( sql , fetch_all = True )
+    return( rows )
+
+
 ####################################################################
 
 def templates_create( tp , tk , tv ) :
