@@ -27,6 +27,9 @@ from . import s_config , s_util
 
 #####################################################################
 
+# FIXME TODO add uptime in log
+# str( int( time.time( ) - uptime_start ) )
+
 log_filepath = False
 log_traceid = False
 
@@ -66,7 +69,7 @@ def default_json( t ) :
 
 #####################################################################
 
-def write( msg_raw ) :
+def write( msg_raw , consoleprint = False ) :
 
     #if not init( ): return
     init( )
@@ -83,10 +86,9 @@ def write( msg_raw ) :
         # FIXME TODO use util json note numpy stuff
         msg = json.dumps( msg , default = default_json , indent=4, sort_keys=True)
 
-    if( isinstance( msg , ( int , float , bool ) ) ) :
+    if( isinstance( msg , ( int , float , bool , os._Environ ) ) ) :
         msg = str( msg )
 
-
     cf = currentframe( ).f_back
 
     frameinfo = getframeinfo( cf )
@@ -102,6 +104,8 @@ def write( msg_raw ) :
     with open( log_filepath , "a+" , 1 ) as log_file :
         log_file.write( msg + "\n" )
 
+    if consoleprint : print( msg )
+
 #####################################################################
 
 def flush( ) :
