@@ -448,6 +448,10 @@ def get_request_response( request_headers = { }  , payload = "" ) :
         s_log.write( "Check endpoint url" )
     if( response.status_code == 502 ) :
         s_log.write( "ERROR 502" )
+    if( response.status_code == 418 ) :
+        s_log.write( "ERROR 418" )
+        s_log.write( "Sleep while tea is brewing" )
+        s_util.sleep( 60 )
 
     time.sleep( 10 )
 
